@@ -293,6 +293,7 @@ static void callback_handler(ffi_cif *cif, void *cb_result, void **cb_args, void
                 args[i - 1].o = type;
                 MVM_gc_root_temp_push(tc, (MVMCollectable **)&(args[i - 1].o));
                 num_roots++;
+                break;
             case MVM_NATIVECALL_ARG_UCHAR:
                 args[i - 1].i64 = *(unsigned char *)cb_args[i - 1];
                 break;
@@ -320,37 +321,7 @@ static void callback_handler(ffi_cif *cif, void *cb_result, void **cb_args, void
     cid.invokee = data->target;
     cid.args    = args;
     cid.cs      = data->cs;
-    {
-        MVMuint8 **backup_interp_cur_op         = tc->interp_cur_op;
-        MVMuint8 **backup_interp_bytecode_start = tc->interp_bytecode_start;
-        MVMRegister **backup_interp_reg_base    = tc->interp_reg_base;
-        MVMCompUnit **backup_interp_cu          = tc->interp_cu;
-        MVMFrame *backup_cur_frame              = MVM_frame_force_to_heap(tc, tc->cur_frame);
-        MVMFrame *backup_thread_entry_frame     = tc->thread_entry_frame;
-        void **backup_jit_return_address        = tc->jit_return_address;
-        tc->jit_return_address                  = NULL;
-
-        MVMROOT2(tc, backup_cur_frame, backup_thread_entry_frame, {
-            MVMuint32 backup_mark                   = MVM_gc_root_temp_mark(tc);
-            jmp_buf backup_interp_jump;
-            memcpy(backup_interp_jump, tc->interp_jump, sizeof(jmp_buf));
-
-            tc->cur_frame->return_value = &res;
-            tc->cur_frame->return_type  = MVM_RETURN_OBJ;
-            MVM_interp_run(tc, callback_invoke, &cid);
-
-            tc->interp_cur_op         = backup_interp_cur_op;
-            tc->interp_bytecode_start = backup_interp_bytecode_start;
-            tc->interp_reg_base       = backup_interp_reg_base;
-            tc->interp_cu             = backup_interp_cu;
-            tc->cur_frame             = backup_cur_frame;
-            tc->current_frame_nr      = backup_cur_frame->sequence_nr;
-            tc->thread_entry_frame    = backup_thread_entry_frame;
-            tc->jit_return_address    = backup_jit_return_address;
-            memcpy(tc->interp_jump, backup_interp_jump, sizeof(jmp_buf));
-            MVM_gc_root_temp_mark_reset(tc, backup_mark);
-        });
-    }
+    MVM_interp_run_nested(tc, callback_invoke, &cid, &res);
 
     /* Handle return value. */
     if (res.o) {
@@ -491,6 +462,12 @@ MVMObject * MVM_nativecall_invoke(MVMThreadContext *tc, MVMObject *res_type,
     /* Get native call body, so we can locate the call info. Read out all we
      * shall need, since later we may allocate a result and and move it. */
     MVMNativeCallBody *body = MVM_nativecall_get_nc_body(tc, site);
+    if (MVM_UNLIKELY(!body->lib_handle)) {
+        MVMROOT3(tc, site, args, res_type, {
+            MVM_nativecall_restore_library(tc, body, site);
+        });
+        body = MVM_nativecall_get_nc_body(tc, site);
+    }
     MVMint16  num_args    = body->num_args;
     MVMint16 *arg_types   = body->arg_types;
     MVMint16  ret_type    = body->ret_type;
