@@ -210,7 +210,7 @@ static void validate_operands(MVMThreadContext *tc, validatorstate *state) {
     int i = 0;
 
     for (i = 0; i < state->cur_op->num_operands; i++) {
-        validate_operand(tc, state, i, state->cur_op->operands[i]);
+        validate_operand(tc, state, i, operands[i]);
     }
 }
 static void validate_op(MVMThreadContext *tc, validatorstate *state) {
@@ -306,13 +306,10 @@ static void validate_op(MVMThreadContext *tc, validatorstate *state) {
     }
     else if (opcode == MVM_OP_getattr_o) {
         MVMuint8 selected_struct_source = state->selected_struct_source; 
-        MVMuint16 target_reg_num;
         MVMuint16 source_reg_num;
         MVMuint32 string_idx;
-        MVMuint16 hint;
         MVMuint16 *hintptr;
 
-        target_reg_num = *((MVMuint16 *)state->bc_pointer);
         validate_operand(tc, state, 0, state->cur_op->operands[0]);
 
         source_reg_num = *((MVMuint16 *)state->bc_pointer);
@@ -324,7 +321,6 @@ static void validate_op(MVMThreadContext *tc, validatorstate *state) {
         validate_operand(tc, state, 3, state->cur_op->operands[3]);
 
         hintptr = (MVMuint16 *)state->bc_pointer;
-        hint = *hintptr;
         validate_operand(tc, state, 4, state->cur_op->operands[4]);
 
         junkprint(stderr, "currently on %d struct source, string index is %d\n", selected_struct_source, string_idx);
@@ -425,7 +421,7 @@ static void validate_op(MVMThreadContext *tc, validatorstate *state) {
     state->prev_op_bc = prev_op_bc_ptr;
 }
 
-MVMuint8 MVM_confprog_validate(MVMThreadContext *tc, MVMConfigurationProgram *prog) {
+void MVM_confprog_validate(MVMThreadContext *tc, MVMConfigurationProgram *prog) {
     validatorstate state;
 
     state.confprog = prog;
@@ -475,7 +471,12 @@ static void error_concreteness(MVMThreadContext *tc, MVMObject *object, MVMuint1
 MVMint16 stats_position_for_value(MVMThreadContext *tc, MVMuint8 entrypoint, MVMuint64 return_value) {
     switch (entrypoint) {
         case MVM_PROGRAM_ENTRYPOINT_PROFILER_STATIC:
-            if (return_value >= MVM_CONFPROG_SF_RESULT_TO_BE_DETERMINED && return_value <= MVM_CONFPROG_SF_RESULT_ALWAYS) {
+            if (return_value == MVM_CONFPROG_SF_RESULT_TO_BE_DETERMINED
+                || return_value == MVM_CONFPROG_SF_RESULT_NEVER
+                || return_value == MVM_CONFPROG_SF_RESULT_DYNAMIC_SUGGEST_NO
+                || return_value == MVM_CONFPROG_SF_RESULT_DYNAMIC_SUGGEST_YES
+                || return_value == MVM_CONFPROG_SF_RESULT_ALWAYS
+            ) {
                 return return_value;
             }
             if (tc)
@@ -487,7 +488,7 @@ MVMint16 stats_position_for_value(MVMThreadContext *tc, MVMuint8 entrypoint, MVM
             MVM_exception_throw_adhoc(tc, "Can't get stats for out-of-bounds value %ld for dynamic profiler entrypoint", return_value);
             return -1;
         case MVM_PROGRAM_ENTRYPOINT_HEAPSNAPSHOT:
-            if (return_value >= 0 && return_value <= 2)
+            if (return_value <= 2)
                 return MVM_CONFPROG_SF_RESULT_ALWAYS + 1 + 1 + 1 + return_value;
             MVM_exception_throw_adhoc(tc, "Can't get stats for out-of-bounds value %ld for heapsnapshot entrypoint", return_value);
             return -1;
@@ -853,7 +854,6 @@ MVMint64 MVM_confprog_run(MVMThreadContext *tc, void *subject, MVMuint8 entrypoi
                 cur_op += 2;
                 goto NEXT;
             OP(exit): {
-                MVMint64 exit_code = GET_REG(cur_op, 0).i64;
                 goto finish_main_loop;
             OP(index_s):
                 debugprint(DEBUG_LVL(TRACE), tc, "index_s into %d with %d and %d starting at %d",
